/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    31-October-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/

#include <stdio.h>
#include "main.h"

/* Exported functions ---------------------------------------------------------*/
extern  uint8_t CAN_Send(CAN_TypeDef *CAN,CanTxMsg *Message);

/* Global Variables ---------------------------------------------------------*/
xQueueHandle xQueueCAN2,xQueueCAN1;

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/*--------------- Tasks Priority -------------*/
#define PERIODIC_SEND_TASK_PRIO   ( tskIDLE_PRIORITY + 2 )
#define BUTTON_SEND_TASK_PRIO   ( tskIDLE_PRIORITY + 2 )

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
void LED_Init(void);

/* Private functions ---------------------------------------------------------*/

/**
  * @brief  CAN1 sends Message and toggles LED orange
  * @param  pvParameters not used
  * @retval None
  */
void vTask_PeriodicSend(void * pvParameters)
{
	uint8_t i;
    CanTxMsg Message1,Message2,Message3;
	static portTickType xLastWakeTime;

	xLastWakeTime = xTaskGetTickCount();

	  Message1.StdId = 0x007;
	  Message1.RTR = CAN_RTR_DATA;
	  Message1.IDE = CAN_ID_STD;
	  Message1.DLC = 8;

	  for(i=0;i<8;i++)
		Message1.Data[i] = 0x55;

	  Message2.StdId = 0x008;
	  Message2.RTR = CAN_RTR_DATA;
	  Message2.IDE = CAN_ID_STD;
	  Message2.DLC = 8;

	  for(i=0;i<8;i++)
	  		Message2.Data[i] = 0x77;

	  Message3.StdId = 0x009;
	  Message3.RTR = CAN_RTR_DATA;
	  Message3.IDE = CAN_ID_STD;
	  Message3.DLC = 8;

	  for(i=0;i<8;i++)
	  		Message3.Data[i] = 0xee;

      for( ;; )
      {

    	/* toggle LED each 250ms */
    	GPIO_ToggleBits(GPIOD, GPIO_Pin_13);


    	CAN_Send(CAN1,&Message1);
    	CAN_Send(CAN1,&Message2);
    	CAN_Send(CAN1,&Message3);

    	vTaskDelayUntil( &xLastWakeTime, 15 );
      }


}
void vTaskCeckButton()
{
	volatile uint8_t i,button=0,button_state=0;
	CanTxMsg Message;
	static portTickType xLastWakeTime;

	xLastWakeTime = xTaskGetTickCount();

	Message.StdId = 0x111;
	Message.RTR = CAN_RTR_DATA;
	Message.IDE = CAN_ID_STD;
	Message.DLC = 1;

	for(i=0;i<8;i++)
		Message.Data[i] = 0x01;

	for( ;; )
    {

#ifdef USE_EDGE_DET


		if(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0)   )
    	{
			if(button_state == 0)
			CAN_Send(CAN1,&Message);
    	}

	button_state=GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_0);
#endif

#ifndef USE_EDGE_DET

	if((button == 1 ))
		{
			CAN_Send(CAN1,&Message);
		}

#endif


	vTaskDelayUntil( &xLastWakeTime, 5 );
    }
}
/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
	SystemInit();

  /*!< At this stage the microcontroller clock setting is already configured to
       168 MHz, this is done through SystemInit() function which is called from
       startup file (startup_stm32f4xx.s) before to branch to application main.
       To reconfigure the default setting of SystemInit() function, refer to
       system_stm32f4xx.c file
     */

  /*Initialize Leds */
  LED_Init();

  /*Configure the Interrupt*/
  InterruptCAN_Init();

  CAN_Initialisierung();

  /* Create Tasks */
  xTaskCreate( vTask_PeriodicSend, NULL, 1048, NULL, PERIODIC_SEND_TASK_PRIO, NULL);
  xTaskCreate( vTaskCeckButton, NULL, 1048, NULL, BUTTON_SEND_TASK_PRIO, NULL);

 /*Enable CAN Interrupt*/
  CAN_ITConfig(CAN2, CAN_IT_FMP0, ENABLE);
 /*Enable CAN Interrupt*/
  CAN_ITConfig(CAN1, CAN_IT_FMP1, ENABLE);

  /* Start scheduler */
  vTaskStartScheduler();

  /* We should never get here as control is now taken by the scheduler */
  for( ;; );
}



/**
  * @brief  Initializes the LEDs resources.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

  /* Initialize Discovery's LEDs */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE);

  /* Configure PD15 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12|GPIO_Pin_13|  GPIO_Pin_14;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOD, &GPIO_InitStructure);

  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA, ENABLE);

  /* Configure PA0 input pulldown mode*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_DOWN;

  GPIO_Init(GPIOA, &GPIO_InitStructure);

}




/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
